@@ -42,7 +42,7 @@ import org.apache.commons.lang3.mutable.MutableObject;
  * {@code [I}. </p>
  *
  * @since 2.0
- * @version $Id: ClassUtils.java 1534839 2013-10-22 22:48:58Z mbenson $
+ * @version $Id: ClassUtils.java 1669311 2015-03-26 10:24:19Z britter $
  */
 public class ClassUtils {
     /**
@@ -50,7 +50,7 @@ public class ClassUtils {
      * @since 3.2
      */
     public enum Interfaces {
-        INCLUDE, EXCLUDE;
+        INCLUDE, EXCLUDE
     }
 
     /**
@@ -127,7 +127,7 @@ public class ClassUtils {
         m.put("char", "C");
         m.put("void", "V");
         final Map<String, String> r = new HashMap<String, String>();
-        for (Map.Entry<String, String> e : m.entrySet()) {
+        for (final Map.Entry<String, String> e : m.entrySet()) {
             r.put(e.getValue(), e.getKey());
         }
         abbreviationMap = Collections.unmodifiableMap(m);
@@ -314,6 +314,87 @@ public class ClassUtils {
         return className.substring(0, i);
     }
 
+    // Abbreviated name
+    // ----------------------------------------------------------------------
+    /**
+     * <p>Gets the abbreviated name of a {@code Class}.</p>
+     *
+     * @param cls  the class to get the abbreviated name for, may be {@code null}
+     * @param len  the desired length of the abbreviated name
+     * @return the abbreviated name or an empty string
+     * @throws IllegalArgumentException if len &lt;= 0
+     * @see #getAbbreviatedName(String, int)
+     * @since 3.4
+     */
+    public static String getAbbreviatedName(final Class<?> cls, int len) {
+      if (cls == null) {
+        return StringUtils.EMPTY;
+      }
+      return getAbbreviatedName(cls.getName(), len);
+    }
+
+    /**
+     * <p>Gets the abbreviated class name from a {@code String}.</p>
+     *
+     * <p>The string passed in is assumed to be a class name - it is not checked.</p>
+     *
+     * <p>The abbreviation algorithm will shorten the class name, usually without
+     * significant loss of meaning.</p>
+     * <p>The abbreviated class name will always include the complete package hierarchy.
+     * If enough space is available, rightmost sub-packages will be displayed in full
+     * length.</p>
+     *
+     * <p>The following table illustrates the algorithm:</p>
+     * <table summary="abbreviation examples">
+     * <tr><td>className</td><td>len</td><td>return</td></tr>
+     * <tr><td>              null</td><td> 1</td><td>""</td></tr>
+     * <tr><td>"java.lang.String"</td><td> 5</td><td>"j.l.String"</td></tr>
+     * <tr><td>"java.lang.String"</td><td>15</td><td>"j.lang.String"</td></tr>
+     * <tr><td>"java.lang.String"</td><td>30</td><td>"java.lang.String"</td></tr>
+     * </table>
+     * @param className  the className to get the abbreviated name for, may be {@code null}
+     * @param len  the desired length of the abbreviated name
+     * @return the abbreviated name or an empty string
+     * @throws IllegalArgumentException if len &lt;= 0
+     * @since 3.4
+     */
+    public static String getAbbreviatedName(String className, int len) {
+      if (len <= 0) {
+        throw new IllegalArgumentException("len must be > 0");
+      }
+      if (className == null) {
+        return StringUtils.EMPTY;
+      }
+
+      int availableSpace = len;
+      int packageLevels = StringUtils.countMatches(className, '.');
+      String[] output = new String[packageLevels + 1];
+      int endIndex = className.length() - 1;
+      for (int level = packageLevels; level >= 0; level--) {
+        int startIndex = className.lastIndexOf('.', endIndex);
+        String part = className.substring(startIndex + 1, endIndex + 1);
+        availableSpace -= part.length();
+        if (level > 0) {
+          // all elements except top level require an additional char space
+          availableSpace--;
+        }
+        if (level == packageLevels) {
+          // ClassName is always complete
+          output[level] = part;
+        } else {
+          if (availableSpace > 0) {
+            output[level] = part;
+          } else {
+            // if no space is left still the first char is used
+            output[level] = part.substring(0, 1);
+          }
+        }
+        endIndex = startIndex - 1;
+      }
+
+      return StringUtils.join(output, '.');
+    }
+
     // Superclasses/Superinterfaces
     // ----------------------------------------------------------------------
     /**
@@ -468,7 +549,7 @@ public class ClassUtils {
      * <p><strong>Since Lang 3.0,</strong> this method will default behavior for
      * calculating assignability between primitive and wrapper types <em>corresponding
      * to the running Java version</em>; i.e. autoboxing will be the default
-     * behavior in VMs running Java versions >= 1.5.</p>
+     * behavior in VMs running Java versions &gt; 1.5.</p>
      *
      * @param classArray  the array of Classes to check, may be {@code null}
      * @param toClassArray  the array of Classes to try to assign into, may be {@code null}
@@ -584,7 +665,7 @@ public class ClassUtils {
      * <p><strong>Since Lang 3.0,</strong> this method will default behavior for
      * calculating assignability between primitive and wrapper types <em>corresponding
      * to the running Java version</em>; i.e. autoboxing will be the default
-     * behavior in VMs running Java versions >= 1.5.</p>
+     * behavior in VMs running Java versions &gt; 1.5.</p>
      *
      * @param cls  the Class to check, may be null
      * @param toClass  the Class to try to assign into, returns false if null
@@ -901,12 +982,13 @@ public class ClassUtils {
      * it ensures that the returned Method is from a public class or interface and not
      * from an anonymous inner class. This means that the Method is invokable and
      * doesn't fall foul of Java bug
-     * <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=4071957">4071957</a>).
+     * <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=4071957">4071957</a>).</p>
      *
-     *  <code><pre>Set set = Collections.unmodifiableSet(...);
+     *  <pre>
+     *  <code>Set set = Collections.unmodifiableSet(...);
      *  Method method = ClassUtils.getPublicMethod(set.getClass(), "isEmpty",  new Class[0]);
-     *  Object result = method.invoke(set, new Object[]);</pre></code>
-     * </p>
+     *  Object result = method.invoke(set, new Object[]);</code>
+     *  </pre>
      *
      * @param cls  the class to check, not null
      * @param methodName  the name of the method
@@ -915,7 +997,7 @@ public class ClassUtils {
      * @throws NullPointerException if the class is null
      * @throws SecurityException if a security violation occurred
      * @throws NoSuchMethodException if the method is not found in the given class
-     *  or if the metothod doen't conform with the requirements
+     *  or if the method doesn't conform with the requirements
      */
     public static Method getPublicMethod(final Class<?> cls, final String methodName, final Class<?>... parameterTypes)
             throws SecurityException, NoSuchMethodException {
@@ -1108,33 +1190,31 @@ public class ClassUtils {
         className = StringUtils.deleteWhitespace(className);
         if (className == null) {
             return null;
+        }
+        int dim = 0;
+        while (className.startsWith("[")) {
+            dim++;
+            className = className.substring(1);
+        }
+        if (dim < 1) {
+            return className;
+        }
+        if (className.startsWith("L")) {
+            className = className.substring(
+                1,
+                className.endsWith(";")
+                    ? className.length() - 1
+                    : className.length());
         } else {
-            int dim = 0;
-            while (className.startsWith("[")) {
-                dim++;
-                className = className.substring(1);
-            }
-            if (dim < 1) {
-                return className;
-            } else {
-                if (className.startsWith("L")) {
-                    className = className.substring(
-                        1,
-                        className.endsWith(";")
-                            ? className.length() - 1
-                            : className.length());
-                } else {
-                    if (className.length() > 0) {
-                        className = reverseAbbreviationMap.get(className.substring(0, 1));
-                    }
-                }
-                final StringBuilder canonicalClassNameBuffer = new StringBuilder(className);
-                for (int i = 0; i < dim; i++) {
-                    canonicalClassNameBuffer.append("[]");
-                }
-                return canonicalClassNameBuffer.toString();
+            if (className.length() > 0) {
+                className = reverseAbbreviationMap.get(className.substring(0, 1));
             }
         }
+        final StringBuilder canonicalClassNameBuffer = new StringBuilder(className);
+        for (int i = 0; i < dim; i++) {
+            canonicalClassNameBuffer.append("[]");
+        }
+        return canonicalClassNameBuffer.toString();
     }
 
     /**
@@ -1157,7 +1237,7 @@ public class ClassUtils {
      * @return Iterable an Iterable over the class hierarchy of the given class
      * @since 3.2
      */
-    public static Iterable<Class<?>> hierarchy(final Class<?> type, Interfaces interfacesBehavior) {
+    public static Iterable<Class<?>> hierarchy(final Class<?> type, final Interfaces interfacesBehavior) {
         final Iterable<Class<?>> classes = new Iterable<Class<?>>() {
     
             @Override
@@ -1218,8 +1298,8 @@ public class ClassUtils {
                         return nextSuperclass;
                     }
     
-                    private void walkInterfaces(Set<Class<?>> addTo, Class<?> c) {
-                        for (Class<?> iface : c.getInterfaces()) {
+                    private void walkInterfaces(final Set<Class<?>> addTo, final Class<?> c) {
+                        for (final Class<?> iface : c.getInterfaces()) {
                             if (!seenInterfaces.contains(iface)) {
                                 addTo.add(iface);
                             }
