@@ -40,7 +40,7 @@ import org.apache.commons.lang3.text.StrBuilder;
  *
  * <p>#ThreadSafe#</p>
  * @since 1.0
- * @version $Id: ObjectUtils.java 1553927 2013-12-28 21:17:57Z ggregory $
+ * @version $Id: ObjectUtils.java 1669786 2015-03-28 15:09:29Z britter $
  */
 //@Immutable
 public class ObjectUtils {
@@ -226,7 +226,7 @@ public class ObjectUtils {
      * @param objects  the objects to obtain the hash code of, may be {@code null}
      * @return the hash code of the objects, or zero if null
      * @since 3.0
-     * @deprecated this method has been replaced by {@code java.util.Objects.hash(Object...)} in Java 7 an will be
+     * @deprecated this method has been replaced by {@code java.util.Objects.hash(Object...)} in Java 7 and will be
      * removed in future releases.
      */
     @Deprecated
@@ -234,7 +234,8 @@ public class ObjectUtils {
         int hash = 1;
         if (objects != null) {
             for (final Object object : objects) {
-                hash = hash * 31 + ObjectUtils.hashCode(object);
+                final int tmpHash = ObjectUtils.hashCode(object);
+                hash = hash * 31 + tmpHash;
             }
         }
         return hash;
@@ -280,7 +281,7 @@ public class ObjectUtils {
      *
      * @param appendable  the appendable to append to
      * @param object  the object to create a toString for
-     * @throws IOException 
+     * @throws IOException if an I/O error occurs
      * @since 3.2
      */
     public static void identityToString(final Appendable appendable, final Object object) throws IOException {
@@ -476,8 +477,8 @@ public class ObjectUtils {
      * @param <T> type of the values processed by this method
      * @param c1  the first comparable, may be null
      * @param c2  the second comparable, may be null
-     * @return a negative value if c1 < c2, zero if c1 = c2
-     *  and a positive value if c1 > c2
+     * @return a negative value if c1 &lt; c2, zero if c1 = c2
+     *  and a positive value if c1 &gt; c2
      */
     public static <T extends Comparable<? super T>> int compare(final T c1, final T c2) {
         return compare(c1, c2, false);
@@ -492,8 +493,8 @@ public class ObjectUtils {
      * @param nullGreater if true {@code null} is considered greater
      *  than a non-{@code null} value or if false {@code null} is
      *  considered less than a Non-{@code null} value
-     * @return a negative value if c1 < c2, zero if c1 = c2
-     *  and a positive value if c1 > c2
+     * @return a negative value if c1 &lt; c2, zero if c1 = c2
+     *  and a positive value if c1 &gt; c2
      * @see java.util.Comparator#compare(Object, Object)
      */
     public static <T extends Comparable<? super T>> int compare(final T c1, final T c2, final boolean nullGreater) {
