@@ -28,7 +28,7 @@ import java.util.Comparator;
  * <p>#ThreadSafe# if the objects and comparator are thread-safe</p>
  * 
  * @since 3.0
- * @version $Id: Range.java 1436770 2013-01-22 07:09:45Z ggregory $
+ * @version $Id: Range.java 1565243 2014-02-06 13:37:12Z sebb $
  */
 public final class Range<T> implements Serializable {
 
@@ -140,25 +140,26 @@ public final class Range<T> implements Serializable {
      *
      * @param element1  the first element, not null
      * @param element2  the second element, not null
-     * @param comparator  the comparator to be used, null for natural ordering
+     * @param comp  the comparator to be used, null for natural ordering
      */
     @SuppressWarnings("unchecked")
-    private Range(final T element1, final T element2, Comparator<T> comparator) {
+    private Range(final T element1, final T element2, final Comparator<T> comp) {
         if (element1 == null || element2 == null) {
             throw new IllegalArgumentException("Elements in a range must not be null: element1=" +
                                                element1 + ", element2=" + element2);
         }
-        if (comparator == null) {
-            comparator = ComparableComparator.INSTANCE;
+        if (comp == null) {
+            this.comparator = ComparableComparator.INSTANCE;
+        } else {
+            this.comparator = comp;            
         }
-        if (comparator.compare(element1, element2) < 1) {
+        if (this.comparator.compare(element1, element2) < 1) {
             this.minimum = element1;
             this.maximum = element2;
         } else {
             this.minimum = element2;
             this.maximum = element1;
         }
-        this.comparator = comparator;
     }
 
     // Accessors
