@@ -20,27 +20,29 @@ import org.apache.commons.lang3.ClassUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.Validate;
 
+import java.lang.annotation.Annotation;
 import java.lang.reflect.Field;
 import java.lang.reflect.Modifier;
 import java.util.ArrayList;
 import java.util.List;
 
 /**
- * Utilities for working with {@link Field}s by reflection. Adapted and refactored from the dormant [reflect] Commons sandbox
- * component.
+ * Utilities for working with {@link Field}s by reflection. Adapted and refactored from the dormant [reflect] Commons
+ * sandbox component.
  * <p>
  * The ability is provided to break the scoping restrictions coded by the programmer. This can allow fields to be
  * changed that shouldn't be. This facility should be used with care.
  * 
  * @since 2.5
- * @version $Id: FieldUtils.java 1546799 2013-12-01 10:34:02Z mcucchiara $
+ * @version $Id: FieldUtils.java 1620579 2014-08-26 11:53:51Z britter $
  */
 public class FieldUtils {
 
     /**
      * {@link FieldUtils} instances should NOT be constructed in standard programming.
      * <p>
-     * This constructor is {@code public} to permit tools that require a JavaBean instance to operate.</p>
+     * This constructor is {@code public} to permit tools that require a JavaBean instance to operate.
+     * </p>
      */
     public FieldUtils() {
         super();
@@ -73,16 +75,17 @@ public class FieldUtils {
      *            the field name to obtain
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @return the Field object
      * @throws IllegalArgumentException
-     *             if the class is {@code null}, or the field name is blank or empty or is matched at
-     *             multiple places in the inheritance hierarchy
+     *             if the class is {@code null}, or the field name is blank or empty or is matched at multiple places
+     *             in the inheritance hierarchy
      */
     public static Field getField(final Class<?> cls, final String fieldName, final boolean forceAccess) {
         Validate.isTrue(cls != null, "The class must not be null");
         Validate.isTrue(StringUtils.isNotBlank(fieldName), "The field name must not be blank/empty");
+        // FIXME is this workaround still needed? lang requires Java 6
         // Sun Java 1.3 has a bugged implementation of getField hence we write the
         // code ourselves
 
@@ -156,8 +159,8 @@ public class FieldUtils {
      *            the field name to obtain
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @return the Field object
      * @throws IllegalArgumentException
      *             if the class is {@code null}, or the field name is blank or empty
@@ -192,7 +195,7 @@ public class FieldUtils {
      *             if the class is {@code null}
      * @since 3.2
      */
-    public static Field[] getAllFields(Class<?> cls) {
+    public static Field[] getAllFields(final Class<?> cls) {
         final List<Field> allFieldsList = getAllFieldsList(cls);
         return allFieldsList.toArray(new Field[allFieldsList.size()]);
     }
@@ -207,13 +210,13 @@ public class FieldUtils {
      *             if the class is {@code null}
      * @since 3.2
      */
-    public static List<Field> getAllFieldsList(Class<?> cls) {
+    public static List<Field> getAllFieldsList(final Class<?> cls) {
         Validate.isTrue(cls != null, "The class must not be null");
         final List<Field> allFields = new ArrayList<Field>();
         Class<?> currentClass = cls;
         while (currentClass != null) {
             final Field[] declaredFields = currentClass.getDeclaredFields();
-            for (Field field : declaredFields) {
+            for (final Field field : declaredFields) {
                 allFields.add(field);
             }
             currentClass = currentClass.getSuperclass();
@@ -221,6 +224,45 @@ public class FieldUtils {
         return allFields;
     }
 
+    /**
+     * Gets all fields of the given class and its parents (if any) that are annotated with the given annotation.
+     * @param cls
+     *            the {@link Class} to query
+     * @param annotationCls
+     *            the {@link Annotation} that must be present on a field to be matched
+     * @return an array of Fields (possibly empty).
+     * @throws IllegalArgumentException
+     *            if the class or annotation are {@code null}
+     * @since 3.4
+     */
+    public static Field[] getFieldsWithAnnotation(final Class<?> cls, final Class<? extends Annotation> annotationCls) {
+        final List<Field> annotatedFieldsList = getFieldsListWithAnnotation(cls, annotationCls);
+        return annotatedFieldsList.toArray(new Field[annotatedFieldsList.size()]);
+    }
+
+    /**
+     * Gets all fields of the given class and its parents (if any) that are annotated with the given annotation.
+     * @param cls
+     *            the {@link Class} to query
+     * @param annotationCls
+     *            the {@link Annotation} that must be present on a field to be matched
+     * @return a list of Fields (possibly empty).
+     * @throws IllegalArgumentException
+     *            if the class or annotation are {@code null}
+     * @since 3.4
+     */
+    public static List<Field> getFieldsListWithAnnotation(final Class<?> cls, final Class<? extends Annotation> annotationCls) {
+        Validate.isTrue(annotationCls != null, "The annotation class must not be null");
+        final List<Field> allFields = getAllFieldsList(cls);
+        final List<Field> annotatedFields = new ArrayList<Field>();
+        for (final Field field : allFields) {
+            if (field.getAnnotation(annotationCls) != null) {
+                annotatedFields.add(field);
+            }
+        }
+        return annotatedFields;
+    }
+
     /**
      * Reads an accessible {@code static} {@link Field}.
      * 
@@ -265,8 +307,8 @@ public class FieldUtils {
      *            the field name to obtain
      * @return the value of the field
      * @throws IllegalArgumentException
-     *             if the class is {@code null}, or the field name is blank or empty,
-     *             is not {@code static}, or could not be found
+     *             if the class is {@code null}, or the field name is blank or empty, is not {@code static}, or could
+     *             not be found
      * @throws IllegalAccessException
      *             if the field is not accessible
      */
@@ -283,12 +325,12 @@ public class FieldUtils {
      *            the field name to obtain
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @return the Field object
      * @throws IllegalArgumentException
-     *             if the class is {@code null}, or the field name is blank or empty,
-     *             is not {@code static}, or could not be found
+     *             if the class is {@code null}, or the field name is blank or empty, is not {@code static}, or could
+     *             not be found
      * @throws IllegalAccessException
      *             if the field is not made accessible
      */
@@ -300,8 +342,8 @@ public class FieldUtils {
     }
 
     /**
-     * Gets the value of a {@code static} {@link Field} by name. The field must be {@code public}.
-     * Only the specified class will be considered.
+     * Gets the value of a {@code static} {@link Field} by name. The field must be {@code public}. Only the specified
+     * class will be considered.
      * 
      * @param cls
      *            the {@link Class} to reflect, must not be {@code null}
@@ -309,8 +351,8 @@ public class FieldUtils {
      *            the field name to obtain
      * @return the value of the field
      * @throws IllegalArgumentException
-     *             if the class is {@code null}, or the field name is blank or empty,
-     *             is not {@code static}, or could not be found
+     *             if the class is {@code null}, or the field name is blank or empty, is not {@code static}, or could
+     *             not be found
      * @throws IllegalAccessException
      *             if the field is not accessible
      */
@@ -319,8 +361,7 @@ public class FieldUtils {
     }
 
     /**
-     * Gets the value of a {@code static} {@link Field} by name.
-     * Only the specified class will be considered.
+     * Gets the value of a {@code static} {@link Field} by name. Only the specified class will be considered.
      * 
      * @param cls
      *            the {@link Class} to reflect, must not be {@code null}
@@ -328,12 +369,12 @@ public class FieldUtils {
      *            the field name to obtain
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @return the Field object
      * @throws IllegalArgumentException
-     *             if the class is {@code null}, or the field name is blank or empty,
-     *             is not {@code static}, or could not be found
+     *             if the class is {@code null}, or the field name is blank or empty, is not {@code static}, or could
+     *             not be found
      * @throws IllegalAccessException
      *             if the field is not made accessible
      */
@@ -396,8 +437,7 @@ public class FieldUtils {
      *            the field name to obtain
      * @return the value of the field
      * @throws IllegalArgumentException
-     *             if the class is {@code null}, or
-     *             the field name is blank or empty or could not be found
+     *             if the class is {@code null}, or the field name is blank or empty or could not be found
      * @throws IllegalAccessException
      *             if the named field is not {@code public}
      */
@@ -414,12 +454,11 @@ public class FieldUtils {
      *            the field name to obtain
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @return the field value
      * @throws IllegalArgumentException
-     *             if {@code target} is {@code null}, or
-     *             the field name is blank or empty or could not be found
+     *             if {@code target} is {@code null}, or the field name is blank or empty or could not be found
      * @throws IllegalAccessException
      *             if the named field is not made accessible
      */
@@ -427,9 +466,9 @@ public class FieldUtils {
         Validate.isTrue(target != null, "target object must not be null");
         final Class<?> cls = target.getClass();
         final Field field = getField(cls, fieldName, forceAccess);
-        Validate.isTrue(field != null, "Cannot locate field %s on %s" , fieldName, cls);
+        Validate.isTrue(field != null, "Cannot locate field %s on %s", fieldName, cls);
         // already forced access above, don't repeat it here:
-        return readField(field, target);
+        return readField(field, target, false);
     }
 
     /**
@@ -441,8 +480,7 @@ public class FieldUtils {
      *            the field name to obtain
      * @return the value of the field
      * @throws IllegalArgumentException
-     *             if {@code target} is {@code null}, or
-     *             the field name is blank or empty or could not be found
+     *             if {@code target} is {@code null}, or the field name is blank or empty or could not be found
      * @throws IllegalAccessException
      *             if the named field is not {@code public}
      */
@@ -451,7 +489,7 @@ public class FieldUtils {
     }
 
     /**
-     * <p<>Gets a {@link Field} value by name. Only the class of the specified object will be considered.
+     * Gets a {@link Field} value by name. Only the class of the specified object will be considered.
      * 
      * @param target
      *            the object to reflect, must not be {@code null}
@@ -459,12 +497,11 @@ public class FieldUtils {
      *            the field name to obtain
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match public fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match public fields.
      * @return the Field object
      * @throws IllegalArgumentException
-     *             if {@code target} is {@code null}, or
-     *             the field name is blank or empty or could not be found
+     *             if {@code target} is {@code null}, or the field name is blank or empty or could not be found
      * @throws IllegalAccessException
      *             if the field is not made accessible
      */
@@ -472,9 +509,9 @@ public class FieldUtils {
         Validate.isTrue(target != null, "target object must not be null");
         final Class<?> cls = target.getClass();
         final Field field = getDeclaredField(cls, fieldName, forceAccess);
-        Validate.isTrue(field != null, "Cannot locate declared field %s.%s" , cls, fieldName);
+        Validate.isTrue(field != null, "Cannot locate declared field %s.%s", cls, fieldName);
         // already forced access above, don't repeat it here:
-        return readField(field, target);
+        return readField(field, target, false);
     }
 
     /**
@@ -485,8 +522,7 @@ public class FieldUtils {
      * @param value
      *            to set
      * @throws IllegalArgumentException
-     *             if the field is {@code null} or not {@code static},
-     *             or {@code value} is not assignable
+     *             if the field is {@code null} or not {@code static}, or {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not {@code public} or is {@code final}
      */
@@ -503,18 +539,17 @@ public class FieldUtils {
      *            to set
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false}
-     *            will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @throws IllegalArgumentException
-     *             if the field is {@code null} or not {@code static},
-     *             or {@code value} is not assignable
+     *             if the field is {@code null} or not {@code static}, or {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not made accessible or is {@code final}
      */
     public static void writeStaticField(final Field field, final Object value, final boolean forceAccess) throws IllegalAccessException {
         Validate.isTrue(field != null, "The field must not be null");
-        Validate.isTrue(Modifier.isStatic(field.getModifiers()), "The field %s.%s is not static",
-                field.getDeclaringClass().getName(), field.getName());
+        Validate.isTrue(Modifier.isStatic(field.getModifiers()), "The field %s.%s is not static", field.getDeclaringClass().getName(),
+                field.getName());
         writeField(field, (Object) null, value, forceAccess);
     }
 
@@ -528,10 +563,8 @@ public class FieldUtils {
      * @param value
      *            to set
      * @throws IllegalArgumentException
-     *             if {@code cls} is {@code null},
-     *             the field name is blank or empty,
-     *             the field cannot be located or is not {@code static}, or
-     *             {@code value} is not assignable
+     *             if {@code cls} is {@code null}, the field name is blank or empty, the field cannot be located or is
+     *             not {@code static}, or {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not {@code public} or is {@code final}
      */
@@ -550,13 +583,11 @@ public class FieldUtils {
      *            to set
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @throws IllegalArgumentException
-     *             if {@code cls} is {@code null},
-     *             the field name is blank or empty,
-     *             the field cannot be located or is not {@code static}, or
-     *             {@code value} is not assignable
+     *             if {@code cls} is {@code null}, the field name is blank or empty, the field cannot be located or is
+     *             not {@code static}, or {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not made accessible or is {@code final}
      */
@@ -565,7 +596,7 @@ public class FieldUtils {
         final Field field = getField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate field %s on %s", fieldName, cls);
         // already forced access above, don't repeat it here:
-        writeStaticField(field, value);
+        writeStaticField(field, value, false);
     }
 
     /**
@@ -578,10 +609,8 @@ public class FieldUtils {
      * @param value
      *            to set
      * @throws IllegalArgumentException
-     *             if {@code cls} is {@code null},
-     *             the field name is blank or empty,
-     *             the field cannot be located or is not {@code static}, or
-     *             {@code value} is not assignable
+     *             if {@code cls} is {@code null}, the field name is blank or empty, the field cannot be located or is
+     *             not {@code static}, or {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not {@code public} or is {@code final}
      */
@@ -602,10 +631,8 @@ public class FieldUtils {
      *            whether to break scope restrictions using the {@code AccessibleObject#setAccessible(boolean)} method.
      *            {@code false} will only match {@code public} fields.
      * @throws IllegalArgumentException
-     *             if {@code cls} is {@code null},
-     *             the field name is blank or empty,
-     *             the field cannot be located or is not {@code static}, or
-     *             {@code value} is not assignable
+     *             if {@code cls} is {@code null}, the field name is blank or empty, the field cannot be located or is
+     *             not {@code static}, or {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not made accessible or is {@code final}
      */
@@ -614,7 +641,7 @@ public class FieldUtils {
         final Field field = getDeclaredField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate declared field %s.%s", cls.getName(), fieldName);
         // already forced access above, don't repeat it here:
-        writeField(field, (Object) null, value);
+        writeField(field, (Object) null, value, false);
     }
 
     /**
@@ -627,8 +654,7 @@ public class FieldUtils {
      * @param value
      *            to set
      * @throws IllegalAccessException
-     *             if the field or target is {@code null},
-     *             the field is not accessible or is {@code final}, or
+     *             if the field or target is {@code null}, the field is not accessible or is {@code final}, or
      *             {@code value} is not assignable
      */
     public static void writeField(final Field field, final Object target, final Object value) throws IllegalAccessException {
@@ -646,11 +672,10 @@ public class FieldUtils {
      *            to set
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @throws IllegalArgumentException
-     *             if the field is {@code null} or
-     *             {@code value} is not assignable
+     *             if the field is {@code null} or {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not made accessible or is {@code final}
      */
@@ -666,24 +691,54 @@ public class FieldUtils {
     }
 
     /**
-     * Remove the final modifier from a {@link Field}
-     * @param field to remove the final modifier
+     * Removes the final modifier from a {@link Field}.
+     * 
+     * @param field
+     *            to remove the final modifier
      * @throws IllegalArgumentException
      *             if the field is {@code null}
+     * @since 3.2
      */
-    public static void removeFinalModifier(Field field)  {
+    public static void removeFinalModifier(final Field field) {
+        removeFinalModifier(field, true);
+    }
+
+    /**
+     * Removes the final modifier from a {@link Field}.
+     * 
+     * @param field
+     *            to remove the final modifier
+     * @param forceAccess
+     *            whether to break scope restrictions using the
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
+     * @throws IllegalArgumentException
+     *             if the field is {@code null}
+     * @since 3.3
+     */
+    public static void removeFinalModifier(final Field field, final boolean forceAccess) {
         Validate.isTrue(field != null, "The field must not be null");
 
         try {
-            if(Modifier.isFinal(field.getModifiers())){
-                Field modifiersField = Field.class.getDeclaredField("modifiers");
-                modifiersField.setAccessible(true);
-                modifiersField.setInt(field, field.getModifiers() & ~Modifier.FINAL);
+            if (Modifier.isFinal(field.getModifiers())) {
+                // Do all JREs implement Field with a private ivar called "modifiers"?
+                final Field modifiersField = Field.class.getDeclaredField("modifiers");
+                final boolean doForceAccess = forceAccess && !modifiersField.isAccessible();
+                if (doForceAccess) {
+                    modifiersField.setAccessible(true);
+                }
+                try {
+                    modifiersField.setInt(field, field.getModifiers() & ~Modifier.FINAL);
+                } finally {
+                    if (doForceAccess) {
+                        modifiersField.setAccessible(false);
+                    }
+                }
             }
-        } catch (NoSuchFieldException ignored) {
+        } catch (final NoSuchFieldException ignored) {
             // The field class contains always a modifiers field
-        } catch (IllegalAccessException ignored) {
-             // The modifiers field is made accessible
+        } catch (final IllegalAccessException ignored) {
+            // The modifiers field is made accessible
         }
     }
 
@@ -697,9 +752,8 @@ public class FieldUtils {
      * @param value
      *            to set
      * @throws IllegalArgumentException
-     *             if {@code target} is {@code null},
-     *             {@code fieldName} is blank or empty or could not be found,
-     *             or {@code value} is not assignable
+     *             if {@code target} is {@code null}, {@code fieldName} is blank or empty or could not be found, or
+     *             {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not accessible
      */
@@ -718,12 +772,11 @@ public class FieldUtils {
      *            to set
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false}
-     *            will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @throws IllegalArgumentException
-     *             if {@code target} is {@code null},
-     *             {@code fieldName} is blank or empty or could not be found,
-     *             or {@code value} is not assignable
+     *             if {@code target} is {@code null}, {@code fieldName} is blank or empty or could not be found, or
+     *             {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not made accessible
      */
@@ -734,7 +787,7 @@ public class FieldUtils {
         final Field field = getField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate declared field %s.%s", cls.getName(), fieldName);
         // already forced access above, don't repeat it here:
-        writeField(field, target, value);
+        writeField(field, target, value, false);
     }
 
     /**
@@ -747,9 +800,8 @@ public class FieldUtils {
      * @param value
      *            to set
      * @throws IllegalArgumentException
-     *             if {@code target} is {@code null},
-     *             {@code fieldName} is blank or empty or could not be found,
-     *             or {@code value} is not assignable
+     *             if {@code target} is {@code null}, {@code fieldName} is blank or empty or could not be found, or
+     *             {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not made accessible
      */
@@ -768,12 +820,11 @@ public class FieldUtils {
      *            to set
      * @param forceAccess
      *            whether to break scope restrictions using the
-     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method.
-     *            {@code false} will only match {@code public} fields.
+     *            {@link java.lang.reflect.AccessibleObject#setAccessible(boolean)} method. {@code false} will only
+     *            match {@code public} fields.
      * @throws IllegalArgumentException
-     *             if {@code target} is {@code null},
-     *             {@code fieldName} is blank or empty or could not be found,
-     *             or {@code value} is not assignable
+     *             if {@code target} is {@code null}, {@code fieldName} is blank or empty or could not be found, or
+     *             {@code value} is not assignable
      * @throws IllegalAccessException
      *             if the field is not made accessible
      */
@@ -784,6 +835,6 @@ public class FieldUtils {
         final Field field = getDeclaredField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate declared field %s.%s", cls.getName(), fieldName);
         // already forced access above, don't repeat it here:
-        writeField(field, target, value);
+        writeField(field, target, value, false);
     }
 }
