@@ -36,7 +36,7 @@ import org.apache.commons.lang3.Validate;
  * parsed from the message pattern.  In this way custom patterns can be specified,
  * and the formats supported by <code>java.text.MessageFormat</code> can be overridden
  * at the format and/or format style level (see MessageFormat).  A "format element"
- * embedded in the message pattern is specified (<b>()?</b> signifies optionality):<br />
+ * embedded in the message pattern is specified (<b>()?</b> signifies optionality):<br>
  * <code>{</code><i>argument-number</i><b>(</b><code>,</code><i>format-name</i><b>
  * (</b><code>,</code><i>format-style</i><b>)?)?</b><code>}</code>
  *
@@ -55,24 +55,22 @@ import org.apache.commons.lang3.Validate;
  * <code>UnsupportedOperationException</code> if called.
  * </p>
  *
- * <p>Limitations inherited from <code>java.text.MessageFormat</code>:
+ * <p>Limitations inherited from <code>java.text.MessageFormat</code>:</p>
  * <ul>
  * <li>When using "choice" subformats, support for nested formatting instructions is limited
  *     to that provided by the base class.</li>
  * <li>Thread-safety of <code>Format</code>s, including <code>MessageFormat</code> and thus
  *     <code>ExtendedMessageFormat</code>, is not guaranteed.</li>
  * </ul>
- * </p>
  *
  * @since 2.4
- * @version $Id: ExtendedMessageFormat.java 1535547 2013-10-24 20:54:34Z bayard $
+ * @version $Id: ExtendedMessageFormat.java 1669787 2015-03-28 15:12:47Z britter $
  */
 public class ExtendedMessageFormat extends MessageFormat {
     private static final long serialVersionUID = -2362048321261811743L;
     private static final int HASH_SEED = 31;
 
     private static final String DUMMY_PATTERN = "";
-    private static final String ESCAPED_QUOTE = "''";
     private static final char START_FMT = ',';
     private static final char END_FE = '}';
     private static final char START_FE = '{';
@@ -158,7 +156,7 @@ public class ExtendedMessageFormat extends MessageFormat {
         while (pos.getIndex() < pattern.length()) {
             switch (c[pos.getIndex()]) {
             case QUOTE:
-                appendQuotedString(pattern, pos, stripCustom, true);
+                appendQuotedString(pattern, pos, stripCustom);
                 break;
             case START_FE:
                 fmtCount++;
@@ -213,7 +211,7 @@ public class ExtendedMessageFormat extends MessageFormat {
      *
      * @param formatElementIndex format element index
      * @param newFormat the new format
-     * @throws UnsupportedOperationException
+     * @throws UnsupportedOperationException always thrown since this isn't supported by ExtendMessageFormat
      */
     @Override
     public void setFormat(final int formatElementIndex, final Format newFormat) {
@@ -225,7 +223,7 @@ public class ExtendedMessageFormat extends MessageFormat {
      *
      * @param argumentIndex argument index
      * @param newFormat the new format
-     * @throws UnsupportedOperationException
+     * @throws UnsupportedOperationException always thrown since this isn't supported by ExtendMessageFormat
      */
     @Override
     public void setFormatByArgumentIndex(final int argumentIndex, final Format newFormat) {
@@ -236,7 +234,7 @@ public class ExtendedMessageFormat extends MessageFormat {
      * Throws UnsupportedOperationException - see class Javadoc for details.
      *
      * @param newFormats new formats
-     * @throws UnsupportedOperationException
+     * @throws UnsupportedOperationException always thrown since this isn't supported by ExtendMessageFormat
      */
     @Override
     public void setFormats(final Format[] newFormats) {
@@ -247,7 +245,7 @@ public class ExtendedMessageFormat extends MessageFormat {
      * Throws UnsupportedOperationException - see class Javadoc for details.
      *
      * @param newFormats new formats
-     * @throws UnsupportedOperationException
+     * @throws UnsupportedOperationException always thrown since this isn't supported by ExtendMessageFormat
      */
     @Override
     public void setFormatsByArgumentIndex(final Format[] newFormats) {
@@ -285,10 +283,9 @@ public class ExtendedMessageFormat extends MessageFormat {
     }
 
     /**
-     * Return the hashcode.
-     *
-     * @return the hashcode
+     * {@inheritDoc}
      */
+    @SuppressWarnings( "deprecation" ) // ObjectUtils.hashCode(Object) has been deprecated in 3.2
     @Override
     public int hashCode() {
         int result = super.hashCode();
@@ -386,7 +383,9 @@ public class ExtendedMessageFormat extends MessageFormat {
                 }
                 break;
             case QUOTE:
-                getQuotedString(pattern, pos, false);
+                getQuotedString(pattern, pos);
+                break;
+            default:
                 break;
             }
         }
@@ -413,7 +412,7 @@ public class ExtendedMessageFormat extends MessageFormat {
             final char c = pattern.charAt(pos.getIndex());
             switch (c) {
             case QUOTE:
-                appendQuotedString(pattern, pos, sb, false);
+                appendQuotedString(pattern, pos, sb);
                 break;
             case START_FE:
                 depth++;
@@ -471,26 +470,23 @@ public class ExtendedMessageFormat extends MessageFormat {
      * @param pattern pattern to parse
      * @param pos current parse position
      * @param appendTo optional StringBuilder to append
-     * @param escapingOn whether to process escaped quotes
      * @return <code>appendTo</code>
      */
     private StringBuilder appendQuotedString(final String pattern, final ParsePosition pos,
-            final StringBuilder appendTo, final boolean escapingOn) {
+            final StringBuilder appendTo) {
+        assert pattern.toCharArray()[pos.getIndex()] == QUOTE : 
+            "Quoted string must start with quote character";
+
+        // handle quote character at the beginning of the string
+        if(appendTo != null) {
+            appendTo.append(QUOTE);
+        }
+        next(pos);
+
         final int start = pos.getIndex();
         final char[] c = pattern.toCharArray();
-        if (escapingOn && c[start] == QUOTE) {
-            next(pos);
-            return appendTo == null ? null : appendTo.append(QUOTE);
-        }
         int lastHold = start;
         for (int i = pos.getIndex(); i < pattern.length(); i++) {
-            if (escapingOn && pattern.substring(i).startsWith(ESCAPED_QUOTE)) {
-                appendTo.append(c, lastHold, pos.getIndex() - lastHold).append(
-                        QUOTE);
-                pos.setIndex(i + ESCAPED_QUOTE.length());
-                lastHold = pos.getIndex();
-                continue;
-            }
             switch (c[pos.getIndex()]) {
             case QUOTE:
                 next(pos);
@@ -509,11 +505,9 @@ public class ExtendedMessageFormat extends MessageFormat {
      *
      * @param pattern pattern to parse
      * @param pos current parse position
-     * @param escapingOn whether to process escaped quotes
      */
-    private void getQuotedString(final String pattern, final ParsePosition pos,
-            final boolean escapingOn) {
-        appendQuotedString(pattern, pos, null, escapingOn);
+    private void getQuotedString(final String pattern, final ParsePosition pos) {
+        appendQuotedString(pattern, pos, null);
     }
 
     /**
