@@ -40,9 +40,15 @@ import java.util.concurrent.TimeUnit;
  * Since a date without a year is not a valid date, you have to decide in what
  * kind of date-field you want your result, for instance milliseconds or days.
  * </p>
+ * <p>
+ * Several methods are provided for adding to {@code Date} objects, of the form 
+ * {@code addXXX(Date date, int amount)}. It is important to note these methods 
+ * use a {@code Calendar} internally (with default timezone and locale) and may
+ * be affected by changes to daylight saving time (DST).
+ * </p>
  *
  * @since 2.0
- * @version $Id: DateUtils.java 1583482 2014-03-31 22:54:57Z niallp $
+ * @version $Id: DateUtils.java 1627984 2014-09-27 17:33:00Z djones $
  */
 public class DateUtils {
 
@@ -111,20 +117,24 @@ public class DateUtils {
     public static final int RANGE_MONTH_MONDAY = 6;
 
     /**
-     * Constant marker for truncating.
-     * @since 3.0
+     * Calendar modification types.
      */
-    private static final int MODIFY_TRUNCATE = 0;
-    /**
-     * Constant marker for rounding.
-     * @since 3.0
-     */
-    private static final int MODIFY_ROUND = 1;
-    /**
-     * Constant marker for ceiling.
-     * @since 3.0
-     */
-    private static final int MODIFY_CEILING = 2;
+    private enum ModifyType {
+        /**
+         * Truncation.
+         */
+        TRUNCATE,
+        
+        /**
+         * Rounding. 
+         */
+        ROUND,
+        
+        /**
+         * Ceiling. 
+         */
+        CEILING
+    }
 
     /**
      * <p>{@code DateUtils} instances should NOT be constructed in
@@ -703,7 +713,7 @@ public class DateUtils {
         }
         final Calendar gval = Calendar.getInstance();
         gval.setTime(date);
-        modify(gval, field, MODIFY_ROUND);
+        modify(gval, field, ModifyType.ROUND);
         return gval.getTime();
     }
 
@@ -739,7 +749,7 @@ public class DateUtils {
             throw new IllegalArgumentException("The date must not be null");
         }
         final Calendar rounded = (Calendar) date.clone();
-        modify(rounded, field, MODIFY_ROUND);
+        modify(rounded, field, ModifyType.ROUND);
         return rounded;
     }
 
@@ -806,7 +816,7 @@ public class DateUtils {
         }
         final Calendar gval = Calendar.getInstance();
         gval.setTime(date);
-        modify(gval, field, MODIFY_TRUNCATE);
+        modify(gval, field, ModifyType.TRUNCATE);
         return gval.getTime();
     }
 
@@ -830,7 +840,7 @@ public class DateUtils {
             throw new IllegalArgumentException("The date must not be null");
         }
         final Calendar truncated = (Calendar) date.clone();
-        modify(truncated, field, MODIFY_TRUNCATE);
+        modify(truncated, field, ModifyType.TRUNCATE);
         return truncated;
     }
 
@@ -886,7 +896,7 @@ public class DateUtils {
         }
         final Calendar gval = Calendar.getInstance();
         gval.setTime(date);
-        modify(gval, field, MODIFY_CEILING);
+        modify(gval, field, ModifyType.CEILING);
         return gval.getTime();
     }
 
@@ -911,7 +921,7 @@ public class DateUtils {
             throw new IllegalArgumentException("The date must not be null");
         }
         final Calendar ceiled = (Calendar) date.clone();
-        modify(ceiled, field, MODIFY_CEILING);
+        modify(ceiled, field, ModifyType.CEILING);
         return ceiled;
     }
 
@@ -954,7 +964,7 @@ public class DateUtils {
      * @param modType  type to truncate, round or ceiling
      * @throws ArithmeticException if the year is over 280 million
      */
-    private static void modify(final Calendar val, final int field, final int modType) {
+    private static void modify(final Calendar val, final int field, final ModifyType modType) {
         if (val.get(Calendar.YEAR) > 280000000) {
             throw new ArithmeticException("Calendar value too large for accurate calculations");
         }
@@ -975,7 +985,7 @@ public class DateUtils {
 
         // truncate milliseconds
         final int millisecs = val.get(Calendar.MILLISECOND);
-        if (MODIFY_TRUNCATE == modType || millisecs < 500) {
+        if (ModifyType.TRUNCATE == modType || millisecs < 500) {
             time = time - millisecs;
         }
         if (field == Calendar.SECOND) {
@@ -984,7 +994,7 @@ public class DateUtils {
 
         // truncate seconds
         final int seconds = val.get(Calendar.SECOND);
-        if (!done && (MODIFY_TRUNCATE == modType || seconds < 30)) {
+        if (!done && (ModifyType.TRUNCATE == modType || seconds < 30)) {
             time = time - (seconds * 1000L);
         }
         if (field == Calendar.MINUTE) {
@@ -993,7 +1003,7 @@ public class DateUtils {
 
         // truncate minutes
         final int minutes = val.get(Calendar.MINUTE);
-        if (!done && (MODIFY_TRUNCATE == modType || minutes < 30)) {
+        if (!done && (ModifyType.TRUNCATE == modType || minutes < 30)) {
             time = time - (minutes * 60000L);
         }
 
@@ -1009,7 +1019,7 @@ public class DateUtils {
             for (final int element : aField) {
                 if (element == field) {
                     //This is our field... we stop looping
-                    if (modType == MODIFY_CEILING || (modType == MODIFY_ROUND && roundUp)) {
+                    if (modType == ModifyType.CEILING || (modType == ModifyType.ROUND && roundUp)) {
                         if (field == DateUtils.SEMI_MONTH) {
                             //This is a special case that's hard to generalize
                             //If the date is 1, we round up to 16, otherwise
@@ -1671,7 +1681,7 @@ public class DateUtils {
 
         long result = 0;
         
-        int offset = (unit == TimeUnit.DAYS) ? 0 : 1;
+        final int offset = (unit == TimeUnit.DAYS) ? 0 : 1;
         
         // Fragments bigger than a day require a breakdown to days
         switch (fragment) {
