@@ -30,7 +30,7 @@ import org.junit.Test;
 /**
  * Unit tests {@link org.apache.commons.lang3.BooleanUtils}.
  *
- * @version $Id: BooleanUtilsTest.java 1534738 2013-10-22 19:23:21Z britter $
+ * @version $Id: BooleanUtilsTest.java 1632874 2014-10-19 05:52:37Z djones $
  */
 public class BooleanUtilsTest {
 
@@ -284,6 +284,8 @@ public class BooleanUtilsTest {
 
         assertEquals(null, BooleanUtils.toBooleanObject("ab"));
         assertEquals(null, BooleanUtils.toBooleanObject("yoo"));
+        assertEquals(null, BooleanUtils.toBooleanObject("true "));
+        assertEquals(null, BooleanUtils.toBooleanObject("ono"));
     }
     
     @Test
@@ -1004,5 +1006,13 @@ public class BooleanUtilsTest {
                     Boolean.TRUE })
                     .booleanValue());
     }
+
+    @Test
+    public void testCompare(){
+        assertTrue(BooleanUtils.compare(true, false) > 0);
+        assertTrue(BooleanUtils.compare(true, true) == 0);
+        assertTrue(BooleanUtils.compare(false, false) == 0);
+        assertTrue(BooleanUtils.compare(false, true) < 0);
+    }
     
 }
