@@ -43,7 +43,7 @@ import org.junit.Test;
 /**
  * Unit tests {@link org.apache.commons.lang3.ObjectUtils}.
  *
- * @version $Id: ObjectUtilsTest.java 1533515 2013-10-18 15:36:22Z sebb $
+ * @version $Id: ObjectUtilsTest.java 1609902 2014-07-12 11:01:37Z britter $
  */
 @SuppressWarnings("deprecation") // deliberate use of deprecated code
 public class ObjectUtilsTest {
@@ -72,15 +72,18 @@ public class ObjectUtilsTest {
 
     @Test
     public void testFirstNonNull() {
-        assertEquals(null, ObjectUtils.firstNonNull(null, null));
         assertEquals("", ObjectUtils.firstNonNull(null, ""));
         final String firstNonNullGenerics = ObjectUtils.firstNonNull(null, null, "123", "456");
         assertEquals("123", firstNonNullGenerics);
         assertEquals("123", ObjectUtils.firstNonNull("123", null, "456", null));
-        assertEquals(null, ObjectUtils.firstNonNull());
         assertSame(Boolean.TRUE, ObjectUtils.firstNonNull(Boolean.TRUE));
-        assertNull(ObjectUtils.firstNonNull());
-        assertNull(ObjectUtils.firstNonNull(null, null));
+        
+        // Explicitly pass in an empty array of Object type to ensure compiler doesn't complain of unchecked generic array creation
+        assertNull(ObjectUtils.firstNonNull(new Object[0]));
+        
+        // Cast to Object in line below ensures compiler doesn't complain of unchecked generic array creation
+        assertNull(ObjectUtils.firstNonNull((Object) null, (Object) null));
+        
 //        assertSame("123", ObjectUtils.firstNonNull(null, ObjectUtils.NULL, "123", "456"));
 //        assertSame("456", ObjectUtils.firstNonNull(ObjectUtils.NULL, "456", "123", null));
 //        assertNull(ObjectUtils.firstNonNull(null, null, ObjectUtils.NULL));
@@ -127,7 +130,7 @@ public class ObjectUtilsTest {
 
     @Test
     public void testHashCodeMulti_multiple_likeList() {
-        final List<Object> list0 = new ArrayList<Object>(Arrays.asList());
+        final List<Object> list0 = new ArrayList<Object>(Arrays.asList(new Object[0]));
         assertEquals(list0.hashCode(), ObjectUtils.hashCodeMulti());
         
         final List<Object> list1 = new ArrayList<Object>(Arrays.asList("a"));
@@ -261,7 +264,7 @@ public class ObjectUtilsTest {
             final Appendable appendable = new StringBuilder();
             ObjectUtils.identityToString(appendable, i);
             assertEquals(expected, appendable.toString());
-        } catch(IOException ex) {
+        } catch(final IOException ex) {
             fail("IOException unexpected");
         }
         
@@ -269,14 +272,14 @@ public class ObjectUtilsTest {
             ObjectUtils.identityToString((Appendable)null, "tmp");
             fail("NullPointerException expected");
         } catch(final NullPointerException npe) {
-        } catch (IOException ex) {
+        } catch (final IOException ex) {
         }
         
         try {
             ObjectUtils.identityToString((Appendable)(new StringBuilder()), null);
             fail("NullPointerException expected");
         } catch(final NullPointerException npe) {
-        } catch (IOException ex) {
+        } catch (final IOException ex) {
         }
     }
 
@@ -285,7 +288,7 @@ public class ObjectUtilsTest {
         assertEquals("", ObjectUtils.toString((Object) null) );
         assertEquals(Boolean.TRUE.toString(), ObjectUtils.toString(Boolean.TRUE) );
     }
-            
+
     @Test
     public void testToString_ObjectString() {
         assertEquals(BAR, ObjectUtils.toString((Object) null, BAR) );
@@ -465,6 +468,8 @@ public class ObjectUtilsTest {
 
     /**
      * Tests {@link ObjectUtils#clone(Object)} with an uncloneable object.
+     *
+     * @throws java.lang.Throwable because we expect this to fail
      */
     @Test(expected = NoSuchMethodException.class)
     public void testCloneOfUncloneable() throws Throwable {
@@ -515,6 +520,8 @@ public class ObjectUtilsTest {
 
     /**
      * Tests {@link ObjectUtils#cloneIfPossible(Object)} with an uncloneable object.
+     *
+     * @throws java.lang.Throwable because we expect this to fail
      */
     @Test(expected = NoSuchMethodException.class)
     public void testPossibleCloneOfUncloneable() throws Throwable {
