@@ -29,7 +29,7 @@ import org.junit.Test;
 /**
  * Unit tests {@link org.apache.commons.lang3.StringUtils} - Substring methods
  *
- * @version $Id: StringUtilsEqualsIndexOfTest.java 1493144 2013-06-14 16:19:27Z sebb $
+ * @version $Id: StringUtilsEqualsIndexOfTest.java 1648063 2014-12-27 16:20:55Z britter $
  */
 public class StringUtilsEqualsIndexOfTest  {
     private static final String BAR = "bar";
@@ -213,6 +213,21 @@ public class StringUtilsEqualsIndexOfTest  {
         assertFalse(StringUtils.containsAny(CharU20000, CharU20001));
         assertFalse(StringUtils.containsAny(CharU20001, CharU20000));
     }
+    
+    @Test
+    public void testContainsAny_StringStringArray() {
+        assertFalse(StringUtils.containsAny(null, (String[]) null));
+        assertFalse(StringUtils.containsAny(null, new String[0]));
+        assertFalse(StringUtils.containsAny(null, new String[] { "hello" }));
+        assertFalse(StringUtils.containsAny("", (String[]) null));
+        assertFalse(StringUtils.containsAny("", new String[0]));
+        assertFalse(StringUtils.containsAny("", new String[] { "hello" }));
+        assertFalse(StringUtils.containsAny("hello, goodbye", (String[]) null));
+        assertFalse(StringUtils.containsAny("hello, goodbye", new String[0]));
+        assertTrue(StringUtils.containsAny("hello, goodbye", new String[] { "hello", "goodbye" }));
+        assertTrue(StringUtils.containsAny("hello, goodbye", new String[] { "hello", "Goodbye" }));
+        assertFalse(StringUtils.containsAny("hello, goodbye", new String[] { "Hello", "Goodbye" }));
+    }
 
     @Test
     public void testContainsIgnoreCase_LocaleIndependence() {
@@ -1006,6 +1021,9 @@ public class StringUtilsEqualsIndexOfTest  {
         assertEquals(7, StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 8));
         assertEquals(8, StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 9));
         assertEquals(-1, StringUtils.ordinalIndexOf("aaaaaaaaa", "a", 10));
+
+        assertEquals(3, StringUtils.ordinalIndexOf("aaaaaa", "aa", 2));
+        assertEquals(-1, StringUtils.ordinalIndexOf("aaaaaa", "aa", 3));
     }
 
 }
