@@ -40,7 +40,7 @@ import org.junit.Test;
 /**
  * Unit tests {@link org.apache.commons.lang3.Validate}.
  *
- * @version $Id: ValidateTest.java 1436770 2013-01-22 07:09:45Z ggregory $
+ * @version $Id: ValidateTest.java 1600868 2014-06-06 12:33:44Z ggregory $
  */
 public class ValidateTest  {
     
@@ -106,6 +106,7 @@ public class ValidateTest  {
 
     //-----------------------------------------------------------------------
     //-----------------------------------------------------------------------
+    @SuppressWarnings("unused")
     @Test
     public void testNotNull1() {
         Validate.notNull(new Object());
@@ -122,6 +123,7 @@ public class ValidateTest  {
     }
 
     //-----------------------------------------------------------------------
+    @SuppressWarnings("unused")
     @Test
     public void testNotNull2() {
         Validate.notNull(new Object(), "MSG");
@@ -835,10 +837,8 @@ public class ValidateTest  {
     public void testInclusiveBetween()
     {
         Validate.inclusiveBetween("a", "c", "b");
-        Validate.inclusiveBetween(0, 2, 1);
-        Validate.inclusiveBetween(0, 2, 2);
         try {
-            Validate.inclusiveBetween(0, 5, 6);
+            Validate.inclusiveBetween("0", "5", "6");
             fail("Expecting IllegalArgumentException");
         } catch (final IllegalArgumentException e) {
             assertEquals("The value 6 is not in the specified inclusive range of 0 to 5", e.getMessage());
@@ -849,6 +849,30 @@ public class ValidateTest  {
     public void testInclusiveBetween_withMessage()
     {
         Validate.inclusiveBetween("a", "c", "b", "Error");
+        try {
+            Validate.inclusiveBetween("0", "5", "6", "Error");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("Error", e.getMessage());
+        }
+    }
+
+    @Test
+    public void testInclusiveBetweenLong()
+    {
+        Validate.inclusiveBetween(0, 2, 1);
+        Validate.inclusiveBetween(0, 2, 2);
+        try {
+            Validate.inclusiveBetween(0, 5, 6);
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("The value 6 is not in the specified inclusive range of 0 to 5", e.getMessage());
+        }
+    }
+
+    @Test
+    public void testInclusiveBetweenLong_withMessage()
+    {
         Validate.inclusiveBetween(0, 2, 1, "Error");
         Validate.inclusiveBetween(0, 2, 2, "Error");
         try {
@@ -858,11 +882,72 @@ public class ValidateTest  {
             assertEquals("Error", e.getMessage());
         }
     }
+
+    @Test
+    public void testInclusiveBetweenDouble()
+    {
+        Validate.inclusiveBetween(0.1, 2.1, 1.1);
+        Validate.inclusiveBetween(0.1, 2.1, 2.1);
+        try {
+            Validate.inclusiveBetween(0.1, 5.1, 6.1);
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("The value 6.1 is not in the specified inclusive range of 0.1 to 5.1", e.getMessage());
+        }
+    }
+
+    @Test
+    public void testInclusiveBetweenDouble_withMessage()
+    {
+        Validate.inclusiveBetween(0.1, 2.1, 1.1, "Error");
+        Validate.inclusiveBetween(0.1, 2.1, 2.1, "Error");
+        try {
+            Validate.inclusiveBetween(0.1, 5.1, 6.1, "Error");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("Error", e.getMessage());
+        }
+    }
     
     @Test
     public void testExclusiveBetween()
     {
         Validate.exclusiveBetween("a", "c", "b");
+        try {
+            Validate.exclusiveBetween("0", "5", "6");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("The value 6 is not in the specified exclusive range of 0 to 5", e.getMessage());
+        }
+        try {
+            Validate.exclusiveBetween("0", "5", "5");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("The value 5 is not in the specified exclusive range of 0 to 5", e.getMessage());
+        }
+    }
+    
+    @Test
+    public void testExclusiveBetween_withMessage()
+    {
+        Validate.exclusiveBetween("a", "c", "b", "Error");
+        try {
+            Validate.exclusiveBetween("0", "5", "6", "Error");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("Error", e.getMessage());
+        }
+        try {
+            Validate.exclusiveBetween("0", "5", "5", "Error");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("Error", e.getMessage());
+        }
+    }
+
+    @Test
+    public void testExclusiveBetweenLong()
+    {
         Validate.exclusiveBetween(0, 2, 1);
         try {
             Validate.exclusiveBetween(0, 5, 6);
@@ -877,11 +962,10 @@ public class ValidateTest  {
             assertEquals("The value 5 is not in the specified exclusive range of 0 to 5", e.getMessage());
         }
     }
-    
+
     @Test
-    public void testExclusiveBetween_withMessage()
+    public void testExclusiveBetweenLong_withMessage()
     {
-        Validate.exclusiveBetween("a", "c", "b", "Error");
         Validate.exclusiveBetween(0, 2, 1, "Error");
         try {
             Validate.exclusiveBetween(0, 5, 6, "Error");
@@ -897,6 +981,42 @@ public class ValidateTest  {
         }
     }
 
+    @Test
+    public void testExclusiveBetweenDouble()
+    {
+        Validate.exclusiveBetween(0.1, 2.1, 1.1);
+        try {
+            Validate.exclusiveBetween(0.1, 5.1, 6.1);
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("The value 6.1 is not in the specified exclusive range of 0.1 to 5.1", e.getMessage());
+        }
+        try {
+            Validate.exclusiveBetween(0.1, 5.1, 5.1);
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("The value 5.1 is not in the specified exclusive range of 0.1 to 5.1", e.getMessage());
+        }
+    }
+
+    @Test
+    public void testExclusiveBetweenDouble_withMessage()
+    {
+        Validate.exclusiveBetween(0.1, 2.1, 1.1, "Error");
+        try {
+            Validate.exclusiveBetween(0.1, 5.1, 6.1, "Error");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("Error", e.getMessage());
+        }
+        try {
+            Validate.exclusiveBetween(0.1, 5.1, 5.1, "Error");
+            fail("Expecting IllegalArgumentException");
+        } catch (final IllegalArgumentException e) {
+            assertEquals("Error", e.getMessage());
+        }
+    }
+
     @Test
     public void testIsInstanceOf() {
         Validate.isInstanceOf(String.class, "hi");
@@ -925,6 +1045,30 @@ public class ValidateTest  {
         }
     }
     
+    @Test
+    public void testIsInstanceOf_withMessageArgs() {
+        Validate.isInstanceOf(String.class, "hi", "Error %s=%s", "Name", "Value");
+        Validate.isInstanceOf(Integer.class, 1, "Error %s=%s", "Name", "Value");
+        try {
+            Validate.isInstanceOf(List.class, "hi", "Error %s=%s", "Name", "Value");
+            fail("Expecting IllegalArgumentException");
+        } catch(final IllegalArgumentException e) {
+            assertEquals("Error Name=Value", e.getMessage());
+        }
+        try {
+            Validate.isInstanceOf(List.class, "hi", "Error %s=%s", List.class, "Value");
+            fail("Expecting IllegalArgumentException");
+        } catch(final IllegalArgumentException e) {
+            assertEquals("Error interface java.util.List=Value", e.getMessage());
+        }
+        try {
+            Validate.isInstanceOf(List.class, "hi", "Error %s=%s", List.class, null);
+            fail("Expecting IllegalArgumentException");
+        } catch(final IllegalArgumentException e) {
+            assertEquals("Error interface java.util.List=null", e.getMessage());
+        }
+    }
+    
     @Test
     public void testIsAssignable() {
         Validate.isAssignableFrom(CharSequence.class, String.class);
