@@ -34,7 +34,7 @@ import static org.junit.Assume.assumeNotNull;
 /**
  * Unit tests FieldUtils
  * 
- * @version $Id: FieldUtilsTest.java 1546799 2013-12-01 10:34:02Z mcucchiara $
+ * @version $Id: FieldUtilsTest.java 1619994 2014-08-23 09:30:12Z britter $
  */
 public class FieldUtilsTest {
 
@@ -43,10 +43,12 @@ public class FieldUtilsTest {
     static final Double D0 = Double.valueOf(0.0);
     static final Double D1 = Double.valueOf(1.0);
 
+    @Annotated
     private PublicChild publicChild;
     private PubliclyShadowedChild publiclyShadowedChild;
+    @Annotated
     private PrivatelyShadowedChild privatelyShadowedChild;
-    private final Class<?> parentClass = PublicChild.class.getSuperclass();
+    private final Class<? super PublicChild> parentClass = PublicChild.class.getSuperclass();
 
     @Before
     public void setUp() {
@@ -166,6 +168,59 @@ public class FieldUtilsTest {
         assertEquals(5, FieldUtils.getAllFieldsList(PublicChild.class).size());
     }
 
+    @Test
+    public void testGetFieldsWithAnnotation() throws NoSuchFieldException {
+        assertArrayEquals(new Field[0], FieldUtils.getFieldsWithAnnotation(Object.class, Annotated.class));
+        final Field[] annotatedFields = new Field[]{
+                FieldUtilsTest.class.getDeclaredField("publicChild"),
+                FieldUtilsTest.class.getDeclaredField("privatelyShadowedChild")
+        };
+        assertArrayEquals(annotatedFields, FieldUtils.getFieldsWithAnnotation(FieldUtilsTest.class, Annotated.class));
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void testGetFieldsWithAnnotationIllegalArgumentException1() {
+        FieldUtils.getFieldsWithAnnotation(FieldUtilsTest.class, null);
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void testGetFieldsWithAnnotationIllegalArgumentException2() {
+        FieldUtils.getFieldsWithAnnotation(null, Annotated.class);
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void testGetFieldsWithAnnotationIllegalArgumentException3() {
+        FieldUtils.getFieldsWithAnnotation(null, null);
+    }
+
+    @Test
+    public void testGetFieldsListWithAnnotation() throws NoSuchFieldException {
+        assertEquals(0, FieldUtils.getFieldsListWithAnnotation(Object.class, Annotated.class).size());
+        final List<Field> annotatedFields = Arrays.asList(
+                FieldUtilsTest.class.getDeclaredField("publicChild"),
+                FieldUtilsTest.class.getDeclaredField("privatelyShadowedChild")
+        );
+        final List<Field> fieldUtilsTestAnnotatedFields = FieldUtils.getFieldsListWithAnnotation(FieldUtilsTest.class, Annotated.class);
+        assertEquals(annotatedFields.size(),fieldUtilsTestAnnotatedFields.size());
+        assertTrue(fieldUtilsTestAnnotatedFields.contains(annotatedFields.get(0)));
+        assertTrue(fieldUtilsTestAnnotatedFields.contains(annotatedFields.get(1)));
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void testGetFieldsListWithAnnotationIllegalArgumentException1() {
+        FieldUtils.getFieldsListWithAnnotation(FieldUtilsTest.class, null);
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void testGetFieldsListWithAnnotationIllegalArgumentException2() {
+        FieldUtils.getFieldsListWithAnnotation(null, Annotated.class);
+    }
+
+    @Test(expected = IllegalArgumentException.class)
+    public void testGetFieldsListWithAnnotationIllegalArgumentException3() {
+        FieldUtils.getFieldsListWithAnnotation(null, null);
+    }
+
     @Test
     public void testGetDeclaredField() {
         assertNull(FieldUtils.getDeclaredField(PublicChild.class, "VALUE"));
@@ -818,28 +873,28 @@ public class FieldUtilsTest {
         assertEquals("new", StaticContainer.getMutablePrivate());
         field = StaticContainer.class.getDeclaredField("IMMUTABLE_PUBLIC");
         try {
-        FieldUtils.writeStaticField(field, "new", true);
+            FieldUtils.writeStaticField(field, "new", true);
             fail("Expected IllegalAccessException");
         } catch (final IllegalAccessException e) {
             // pass
         }
         field = StaticContainer.class.getDeclaredField("IMMUTABLE_PROTECTED");
         try {
-        FieldUtils.writeStaticField(field, "new", true);
+            FieldUtils.writeStaticField(field, "new", true);
             fail("Expected IllegalAccessException");
         } catch (final IllegalAccessException e) {
             // pass
         }
         field = StaticContainer.class.getDeclaredField("IMMUTABLE_PACKAGE");
         try {
-        FieldUtils.writeStaticField(field, "new", true);
+            FieldUtils.writeStaticField(field, "new", true);
             fail("Expected IllegalAccessException");
         } catch (final IllegalAccessException e) {
             // pass
         }
         field = StaticContainer.class.getDeclaredField("IMMUTABLE_PRIVATE");
         try {
-        FieldUtils.writeStaticField(field, "new", true);
+            FieldUtils.writeStaticField(field, "new", true);
             fail("Expected IllegalAccessException");
         } catch (final IllegalAccessException e) {
             // pass
@@ -1029,12 +1084,14 @@ public class FieldUtilsTest {
         field = parentClass.getDeclaredField("i");
         try {
             FieldUtils.writeField(field, publicChild, Integer.valueOf(Integer.MAX_VALUE));
+            fail("Expected IllegalAccessException");
         } catch (final IllegalAccessException e) {
             // pass
         }
         field = parentClass.getDeclaredField("d");
         try {
             FieldUtils.writeField(field, publicChild, Double.valueOf(Double.MAX_VALUE));
+            fail("Expected IllegalAccessException");
         } catch (final IllegalAccessException e) {
             // pass
         }
@@ -1255,9 +1312,46 @@ public class FieldUtilsTest {
 
     @Test
     public void testRemoveFinalModifier() throws Exception {
-        Field field = StaticContainer.class.getDeclaredField("IMMUTABLE_PRIVATE_2");
+        final Field field = StaticContainer.class.getDeclaredField("IMMUTABLE_PRIVATE_2");
+        assertFalse(field.isAccessible());
         assertTrue(Modifier.isFinal(field.getModifiers()));
         FieldUtils.removeFinalModifier(field);
+        // The field is no longer final
         assertFalse(Modifier.isFinal(field.getModifiers()));
+        assertFalse(field.isAccessible());
     }
+    
+    @Test
+    public void testRemoveFinalModifierWithAccess() throws Exception {
+        final Field field = StaticContainer.class.getDeclaredField("IMMUTABLE_PRIVATE_2");
+        assertFalse(field.isAccessible());
+        assertTrue(Modifier.isFinal(field.getModifiers()));
+        FieldUtils.removeFinalModifier(field, true);
+        // The field is no longer final
+        assertFalse(Modifier.isFinal(field.getModifiers()));
+        assertFalse(field.isAccessible());
+    }
+
+    @Test
+    public void testRemoveFinalModifierWithoutAccess() throws Exception {
+        final Field field = StaticContainer.class.getDeclaredField("IMMUTABLE_PRIVATE_2");
+        assertFalse(field.isAccessible());
+        assertTrue(Modifier.isFinal(field.getModifiers()));
+        FieldUtils.removeFinalModifier(field, false);
+        // The field is STILL final because we did not force access
+        assertTrue(Modifier.isFinal(field.getModifiers()));
+        assertFalse(field.isAccessible());
+    }
+
+    @Test
+    public void testRemoveFinalModifierAccessNotNeeded() throws Exception {
+        final Field field = StaticContainer.class.getDeclaredField("IMMUTABLE_PACKAGE");
+        assertFalse(field.isAccessible());
+        assertTrue(Modifier.isFinal(field.getModifiers()));
+        FieldUtils.removeFinalModifier(field, false);
+        // The field is no longer final AND we did not need to force access
+        assertTrue(Modifier.isFinal(field.getModifiers()));
+        assertFalse(field.isAccessible());
+    }
+
 }
