@@ -27,13 +27,11 @@ import java.util.List;
 import java.util.NoSuchElementException;
 
 import org.apache.commons.lang3.ArrayUtils;
-import org.apache.commons.lang3.ObjectUtils;
 
 /**
  * Unit test for Tokenizer.
  * 
  */
-@SuppressWarnings("deprecation") // deliberate use of deprecated code
 public class StrTokenizerTest {
 
     private static final String CSV_SIMPLE_FIXTURE = "A,b,c";
@@ -61,8 +59,8 @@ public class StrTokenizerTest {
 
         assertEquals(ArrayUtils.toString(tokens), expected.length, tokens.length);
         for (int i = 0; i < expected.length; i++) {
-            assertTrue("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
-                    ObjectUtils.equals(expected[i], tokens[i]));
+            assertEquals("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
+                    expected[i], tokens[i]);
         }
 
     }
@@ -82,8 +80,8 @@ public class StrTokenizerTest {
 
         assertEquals(ArrayUtils.toString(tokens), expected.length, tokens.length);
         for (int i = 0; i < expected.length; i++) {
-            assertTrue("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
-                    ObjectUtils.equals(expected[i], tokens[i]));
+            assertEquals("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
+                    expected[i], tokens[i]);
         }
 
     }
@@ -103,8 +101,8 @@ public class StrTokenizerTest {
 
         assertEquals(ArrayUtils.toString(tokens), expected.length, tokens.length);
         for (int i = 0; i < expected.length; i++) {
-            assertTrue("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
-                    ObjectUtils.equals(expected[i], tokens[i]));
+            assertEquals("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
+                    expected[i], tokens[i]);
         }
 
     }
@@ -124,8 +122,8 @@ public class StrTokenizerTest {
 
         assertEquals(ArrayUtils.toString(tokens), expected.length, tokens.length);
         for (int i = 0; i < expected.length; i++) {
-            assertTrue("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
-                    ObjectUtils.equals(expected[i], tokens[i]));
+            assertEquals("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
+                    expected[i], tokens[i]);
         }
 
     }
@@ -146,8 +144,8 @@ public class StrTokenizerTest {
 
         assertEquals(ArrayUtils.toString(tokens), expected.length, tokens.length);
         for (int i = 0; i < expected.length; i++) {
-            assertTrue("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
-                    ObjectUtils.equals(expected[i], tokens[i]));
+            assertEquals("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
+                    expected[i], tokens[i]);
         }
 
     }
@@ -203,8 +201,8 @@ public class StrTokenizerTest {
 
         assertEquals(ArrayUtils.toString(tokens), expected.length, tokens.length);
         for (int i = 0; i < expected.length; i++) {
-            assertTrue("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
-                    ObjectUtils.equals(expected[i], tokens[i]));
+            assertEquals("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
+                    expected[i], tokens[i]);
         }
 
     }
@@ -224,8 +222,8 @@ public class StrTokenizerTest {
 
         assertEquals(ArrayUtils.toString(tokens), expected.length, tokens.length);
         for (int i = 0; i < expected.length; i++) {
-            assertTrue("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
-                    ObjectUtils.equals(expected[i], tokens[i]));
+            assertEquals("token[" + i + "] was '" + tokens[i] + "' but was expected to be '" + expected[i] + "'",
+                    expected[i], tokens[i]);
         }
 
     }
